@@ -46,42 +46,47 @@ Implementation Notes
 * Adafruit's Bus Device library: https://github.com/adafruit/Adafruit_CircuitPython_BusDevice
 """
 import time
+
 try:
     import ustruct as struct
 except ImportError:
     import struct
 
+__version__ = "0.0.0-auto.0"
+__repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_FXAS21002C.git"
+
 import adafruit_bus_device.i2c_device as i2c_dev
 from micropython import const
 
 
 # Internal constants and register values:
 # pylint: disable=bad-whitespace
-_FXAS21002C_ADDRESS       = const(0x21)  # 0100001
-_FXAS21002C_ID            = const(0xD7)       # 1101 0111
-_GYRO_REGISTER_STATUS     = const(0x00)
-_GYRO_REGISTER_OUT_X_MSB  = const(0x01)
-_GYRO_REGISTER_OUT_X_LSB  = const(0x02)
-_GYRO_REGISTER_OUT_Y_MSB  = const(0x03)
-_GYRO_REGISTER_OUT_Y_LSB  = const(0x04)
-_GYRO_REGISTER_OUT_Z_MSB  = const(0x05)
-_GYRO_REGISTER_OUT_Z_LSB  = const(0x06)
-_GYRO_REGISTER_WHO_AM_I   = const(0x0C)   # 11010111   r
-_GYRO_REGISTER_CTRL_REG0  = const(0x0D)  # 00000000   r/w
-_GYRO_REGISTER_CTRL_REG1  = const(0x13)  # 00000000   r/w
-_GYRO_REGISTER_CTRL_REG2  = const(0x14)  # 00000000   r/w
-_GYRO_SENSITIVITY_250DPS  = 0.0078125    # Table 35 of datasheet
-_GYRO_SENSITIVITY_500DPS  = 0.015625     # ..
-_GYRO_SENSITIVITY_1000DPS = 0.03125     # ..
-_GYRO_SENSITIVITY_2000DPS = 0.0625      # ..
+_FXAS21002C_ADDRESS = const(0x21)  # 0100001
+_FXAS21002C_ID = const(0xD7)  # 1101 0111
+_GYRO_REGISTER_STATUS = const(0x00)
+_GYRO_REGISTER_OUT_X_MSB = const(0x01)
+_GYRO_REGISTER_OUT_X_LSB = const(0x02)
+_GYRO_REGISTER_OUT_Y_MSB = const(0x03)
+_GYRO_REGISTER_OUT_Y_LSB = const(0x04)
+_GYRO_REGISTER_OUT_Z_MSB = const(0x05)
+_GYRO_REGISTER_OUT_Z_LSB = const(0x06)
+_GYRO_REGISTER_WHO_AM_I = const(0x0C)  # 11010111   r
+_GYRO_REGISTER_CTRL_REG0 = const(0x0D)  # 00000000   r/w
+_GYRO_REGISTER_CTRL_REG1 = const(0x13)  # 00000000   r/w
+_GYRO_REGISTER_CTRL_REG2 = const(0x14)  # 00000000   r/w
+_GYRO_SENSITIVITY_250DPS = 0.0078125  # Table 35 of datasheet
+_GYRO_SENSITIVITY_500DPS = 0.015625  # ..
+_GYRO_SENSITIVITY_1000DPS = 0.03125  # ..
+_GYRO_SENSITIVITY_2000DPS = 0.0625  # ..
 
 # User facing constants/module globals:
-GYRO_RANGE_250DPS   = 250
-GYRO_RANGE_500DPS   = 500
-GYRO_RANGE_1000DPS  = 1000
-GYRO_RANGE_2000DPS  = 2000
+GYRO_RANGE_250DPS = 250
+GYRO_RANGE_500DPS = 500
+GYRO_RANGE_1000DPS = 1000
+GYRO_RANGE_2000DPS = 2000
 # pylint: enable=bad-whitespace
 
+
 class FXAS21002C:
     """Driver for the NXP FXAS21002C gyroscope."""
 
@@ -90,15 +95,18 @@ class FXAS21002C:
     # thread safe!
     _BUFFER = bytearray(7)
 
-    def __init__(self, i2c, address=_FXAS21002C_ADDRESS,
-                 gyro_range=GYRO_RANGE_250DPS):
-        assert gyro_range in (GYRO_RANGE_250DPS, GYRO_RANGE_500DPS,
-                              GYRO_RANGE_1000DPS, GYRO_RANGE_2000DPS)
+    def __init__(self, i2c, address=_FXAS21002C_ADDRESS, gyro_range=GYRO_RANGE_250DPS):
+        assert gyro_range in (
+            GYRO_RANGE_250DPS,
+            GYRO_RANGE_500DPS,
+            GYRO_RANGE_1000DPS,
+            GYRO_RANGE_2000DPS,
+        )
         self._gyro_range = gyro_range
         self._device = i2c_dev.I2CDevice(i2c, address)
         # Check for chip ID value.
         if self._read_u8(_GYRO_REGISTER_WHO_AM_I) != _FXAS21002C_ID:
-            raise RuntimeError('Failed to find FXAS21002C, check wiring!')
+            raise RuntimeError("Failed to find FXAS21002C, check wiring!")
         ctrl_reg0 = 0x00
         if gyro_range == GYRO_RANGE_250DPS:
             ctrl_reg0 = 0x03
@@ -112,18 +120,17 @@ class FXAS21002C:
         # Putting into standy doesn't work as the chip becomes instantly
         # unresponsive.  Perhaps CircuitPython is too slow to go into standby
         # and send reset?  Keep these two commented for now:
-        #self._write_u8(_GYRO_REGISTER_CTRL_REG1, 0x00)     # Standby)
-        #self._write_u8(_GYRO_REGISTER_CTRL_REG1, (1<<6))   # Reset
-        self._write_u8(_GYRO_REGISTER_CTRL_REG0, ctrl_reg0) # Set sensitivity
-        self._write_u8(_GYRO_REGISTER_CTRL_REG1, 0x0E)     # Active
-        time.sleep(0.1) # 60 ms + 1/ODR
+        # self._write_u8(_GYRO_REGISTER_CTRL_REG1, 0x00)     # Standby)
+        # self._write_u8(_GYRO_REGISTER_CTRL_REG1, (1<<6))   # Reset
+        self._write_u8(_GYRO_REGISTER_CTRL_REG0, ctrl_reg0)  # Set sensitivity
+        self._write_u8(_GYRO_REGISTER_CTRL_REG1, 0x0E)  # Active
+        time.sleep(0.1)  # 60 ms + 1/ODR
 
     def _read_u8(self, address):
         # Read an 8-bit unsigned value from the specified 8-bit address.
         with self._device as i2c:
             self._BUFFER[0] = address & 0xFF
-            i2c.write_then_readinto(self._BUFFER, self._BUFFER,
-                                    out_end=1, in_end=1, stop=False)
+            i2c.write_then_readinto(self._BUFFER, self._BUFFER, out_end=1, in_end=1)
         return self._BUFFER[0]
 
     def _write_u8(self, address, val):
@@ -141,12 +148,11 @@ class FXAS21002C:
         # Read gyro data from the sensor.
         with self._device as i2c:
             self._BUFFER[0] = _GYRO_REGISTER_OUT_X_MSB
-            i2c.write_then_readinto(self._BUFFER, self._BUFFER,
-               	                    out_end=1, stop=False)
+            i2c.write_then_readinto(self._BUFFER, self._BUFFER, out_end=1)
         # Parse out the gyroscope data as 16-bit signed data.
-        raw_x = struct.unpack_from('>h', self._BUFFER[0:2])[0]
-        raw_y = struct.unpack_from('>h', self._BUFFER[2:4])[0]
-        raw_z = struct.unpack_from('>h', self._BUFFER[4:6])[0]
+        raw_x = struct.unpack_from(">h", self._BUFFER[0:2])[0]
+        raw_y = struct.unpack_from(">h", self._BUFFER[2:4])[0]
+        raw_z = struct.unpack_from(">h", self._BUFFER[4:6])[0]
         return (raw_x, raw_y, raw_z)
 
     # pylint is confused and incorrectly marking this function as bad return
